import _ from 'lodash/fp'

const collector = ({ pagination, warnings = {} }) => files => {
  const { onlyOneArticle = false, sameURL = true } = warnings
  const tags = {}
  const tagList = []
  let warned = false
  files.forEach(file => {
    if(file.metadata.tags)
    for(const tag of file.metadata.tags) {
      const tagname = _.flow(
        _.deburr,
        _.toLower,
        _.replace(' ','-'),
        _.replace(/[^a-zA-Z-0-9]+/g, ''),
      )(tag)
      if(!tags[tagname]) {
        const obj = { deburr: tagname, tag, list: [] }
        tags[tagname] = obj
        tagList.push(obj)
      }
      tags[tagname].list.push(file)
      const warn = () => { if(!warned) { console.log(); warned = true } }
      if(sameURL && tags[tagname].tag !== tag) {
        warn()
        console.error(`WARNING: Name of tag "${tag}" is not same as "${tags[tagname].tag}" but they correspond to same url of "${tagname}"`)
        console.error(`         In files ${file.metadata.filename} and ${tags[tagname].list[0].metadata.filename}`)
      }
      if(onlyOneArticle && tags[tagname].list.length < 2) {
        warn()
        console.error(`WARNING: Tag "${tag}" only has one article. Consider removing it or adding it more articles.`)
        console.error(`         In file ${file.metadata.filename}`)
      }
    }
  })
  const tagPages = tagList.reduce((list, tag) => {
    const chunks = _.chunk(pagination, tag.list)
    const paginator = chunks.map((chunk, index) => '/tag/'+tag.deburr+(index?'/'+(index+1):''))
    return list.concat(chunks.map(
      (chunk, index) => ({
        type: 'tag',
        metadata: {
          url: paginator[index],
          name: tag.tag,
          paginator,
        },
        content: chunk
      })
    ))
  }, [])
  return files.map(
    article => ({ ...article, type: 'article' })
  ).concat(tagPages)
  //console.log(tagList)
}

export default collector
