import _ from 'lodash/fp'
import fs from 'fs'

import {readFiles} from './readFiles'
import parser from './parser'
import markdownToJSON from './markdownToJSON'
import collectTags from './collectTags'

const buildStep = (desc, func) => f => {
  const start = new Date();
  const msg = `- ${desc}`
  process.stdout.write(msg)
  const ret = func(f)
  process.stdout.write(_.repeat(30-msg.length,' '))
  process.stdout.write(`${(new Date()-start)}ms\n`)
  return ret
}

const map = (desc, func) => buildStep(desc, f => f.map(func))

let start
readFiles({
  filter: file => !/\.git$/.exec(file)
})(change => console.log(change))
.then(f => (start = new Date()) && f)
.then(map('Parsing files', f => parser(f)))
.then(map('Parsing markdown', f => ({ metadata: f.metadata, content: markdownToJSON(f.content) })))
.then(map('Rewriting URLs', f => ({
  metadata: {
    ...f.metadata,
    url: '/clanek/' + f.metadata.filename.replace(/\.md$/,'')
  },
  content: f.content
})))
.then(buildStep('Collect tags', collectTags({
  pagination: 6,
  warnings: {
    onlyOneArticle: false,
    sameURL: false,
  }
})))
//.then(f => console.log(f))
.then(() => console.log(`                       Total: ${(new Date())-start}ms`))
.catch(e => console.log(e))
