import _ from 'lodash/fp'
import metadataParser from './metadataParser'

const splitParts = data => {
  const delimiter = data.split('\n', 1)[0]
  const header = data.split('\n'+delimiter+'\n',1)[0].substring(delimiter.length+1)
  const body = data.substring(
    delimiter.length + 1 // delimiter \n
    + header.length + 1 // header \n
    + delimiter.length + 1 // delimiter \n
    )
  return {header, body}
}

const parser = page => {
  const {header, body} = splitParts(page.content)
  let line, column
  const metadata = metadataParser(header, {
    lineColumnPrinter: (l, c) => {
      line = l
      column = c
      return `on line ${l+1} column ${c} in file ${page.metadata.filename}`
    }
  })
  if(metadata._error) {
    console.log(_.repeat(80, '='))
    console.log(header.split('\n')[line-1])
    console.log(_.repeat(column-1, '-')+'^')
    console.log(metadata._error)
    return undefined
  }
  return {
    ...page,
    metadata: {...page.metadata, ...metadata},
    content: body,
  }
}

export default parser
